@@ -17,34 +17,34 @@ class ColorSpace(IntEnum):
 class ExifMarkers:
     """EXIF marker segments bytes."""
 
-    SEG_PREFIX = "FF"
+    SEG_PREFIX = b"\xff"
     """Generic Segment Prefix"""
 
-    SOI = "FFD8"
+    SOI = SEG_PREFIX + b"\xd8"
     """Start of Image"""
 
-    APP1 = "FFE1"
+    APP1 = SEG_PREFIX + b"\xe1"
     """EXIF Attribute Information (Application Segment 1)"""
 
-    APP2 = "FFE2"
+    APP2 = SEG_PREFIX + b"\xe2"
     """EXIF Extended Data (Application Segment 2)"""
 
-    DQT = "FFDB"
+    DQT = SEG_PREFIX + b"\xdb"
     """Quantization Table Definition"""
 
-    DHT = "FFC4"
+    DHT = SEG_PREFIX + b"\xc4"
     """Huffman Table Definition"""
 
-    DRI = "FFDD"
+    DRI = SEG_PREFIX + b"\xdd"
     """Restart Interoperability Definition"""
 
-    SOF = "FFC0"
+    SOF = SEG_PREFIX + b"\xc0"
     """Start of Frame"""
 
-    SOS = "FFDA"
+    SOS = SEG_PREFIX + b"\xda"
     """Start of Scan"""
 
-    EOI = "FFD9"
+    EOI = SEG_PREFIX + b"\xd9"
     """End of Image"""
 
 
@@ -117,6 +117,83 @@ class ExposureProgram(IntEnum):
     """Landscape Kode (For Landscape Photos with the Background in Focus)"""
 
 
+class GpsAltitudeRef(IntEnum):
+    """Altitude used as the reference altitude."""
+
+    ABOVE_SEA_LEVEL = 0
+    """Above Sea Level"""
+
+    BELOW_SEA_LEVEL = 1
+    """Below Sea Level"""
+
+
+class LightSource(IntEnum):
+    """Class of the program used by the camera to set exposure when the picture is taken."""
+
+    UNKNOWN = 0
+    """Unknown"""
+
+    DAYLIGHT = 1
+    """Daylight"""
+
+    FLUORESCENT = 2
+    """Fluorescent"""
+
+    TUNGSTEN = 3
+    """Tungsten (Incandescent Light)"""
+
+    FLASH = 4
+    """Flash"""
+
+    FINE_WEATHER = 9
+    """Fine Weather"""
+
+    CLOUDY_WEATHER = 10
+    """Cloudy Weather"""
+
+    SHADE = 11
+    """Shade"""
+
+    DAYLIGHT_FLUORESCENT = 12
+    """Daylight Fluorescent (D 5700 - 7100K)"""
+
+    DAY_WHITE_FLUORESCENT = 13
+    """Day White Fluorescent (N 4600 - 5400K)"""
+
+    COOL_WHITE_FLUORESCENT = 14
+    """Cool White Fluorescent (W 3900 - 4500K)"""
+
+    WHITE_FLUORESCENT = 15
+    """White Fluorescent (WW 3200 - 3700K)"""
+
+    STANDARD_LIGHT_A = 17
+    """Standard Light A"""
+
+    STANDARD_LIGHT_B = 18
+    """Standard Light B"""
+
+    STANDARD_LIGHT_C = 19
+    """Standard Light C"""
+
+    D55 = 20
+    """D55"""
+
+    D65 = 21
+    """D65"""
+
+    D75 = 22
+    """D75"""
+
+    D50 = 23
+    """D50"""
+
+    ISO_STUDIO_TUNGSTEN = 24
+    """ISO Studio Tungsten"""
+
+    OTHER = 255
+    """Other Light Source"""
+
+
 class MeteringMode(IntEnum):
     """Metering mode."""
 
@@ -428,29 +505,85 @@ ATTRIBUTE_ID_MAP = {
 
 ATTRIBUTE_NAME_MAP = {value: key for key, value in ATTRIBUTE_ID_MAP.items()}
 
-BYTES_PER_IFD_TAG_ID = 2
+ATTRIBUTE_TYPE_MAP = {  # tuple of type ID and IFD number description used when adding new tags
+    "aperture_value": (int(ExifTypes.RATIONAL), "exif"),
+    "artist": (int(ExifTypes.ASCII), 0),
+    "brightness_value": (int(ExifTypes.SRATIONAL), "exif"),
+    "color_space": (int(ExifTypes.SHORT), "exif"),
+    "contrast": (int(ExifTypes.SHORT), "exif"),
+    "copyright": (int(ExifTypes.ASCII), 0),
+    "custom_rendered": (int(ExifTypes.SHORT), "exif"),
+    "datetime": (int(ExifTypes.ASCII), 0),
+    "datetime_digitized": (int(ExifTypes.ASCII), "exif"),
+    "datetime_original": (int(ExifTypes.ASCII), "exif"),
+    "digital_zoom_ratio": (int(ExifTypes.RATIONAL), "exif"),
+    "exposure_bias_value": (int(ExifTypes.SRATIONAL), "exif"),
+    "exposure_index": (int(ExifTypes.RATIONAL), "exif"),
+    "exposure_mode": (int(ExifTypes.SHORT), "exif"),
+    "exposure_program": (int(ExifTypes.SHORT), "exif"),
+    "exposure_time": (int(ExifTypes.RATIONAL), "exif"),
+    "f_number": (int(ExifTypes.RATIONAL), "exif"),
+    "flash": (int(ExifTypes.SHORT), "exif"),
+    "flash_energy": (int(ExifTypes.RATIONAL), "exif"),
+    "focal_length_in_35mm_film": (int(ExifTypes.SHORT), "exif"),
+    "focal_plane_resolution_unit": (int(ExifTypes.SHORT), "exif"),
+    "gain_control": (int(ExifTypes.RATIONAL), "exif"),
+    "gps_altitude": (int(ExifTypes.RATIONAL), "gps"),
+    "gps_altitude_ref": (int(ExifTypes.BYTE), "gps"),
+    "gps_datestamp": (int(ExifTypes.ASCII), "gps"),
+    "gps_dest_bearing": (int(ExifTypes.RATIONAL), "gps"),
+    "gps_dest_bearing_ref": (int(ExifTypes.ASCII), "gps"),
+    "gps_dest_distance": (int(ExifTypes.RATIONAL), "gps"),
+    "gps_dest_distance_ref": (int(ExifTypes.ASCII), "gps"),
+    "gps_dest_latitude": (int(ExifTypes.RATIONAL), "gps"),
+    "gps_dest_latitude_ref": (int(ExifTypes.ASCII), "gps"),
+    "gps_dest_longitude": (int(ExifTypes.RATIONAL), "gps"),
+    "gps_dest_longitude_ref": (int(ExifTypes.ASCII), "gps"),
+    "gps_differential": (int(ExifTypes.SHORT), "gps"),
+    "gps_dop": (int(ExifTypes.RATIONAL), "gps"),
+    "gps_img_direction": (int(ExifTypes.RATIONAL), "gps"),
+    "gps_img_direction_ref": (int(ExifTypes.ASCII), "gps"),
+    "gps_latitude": (int(ExifTypes.RATIONAL), "gps"),
+    "gps_latitude_ref": (int(ExifTypes.ASCII), "gps"),
+    "gps_longitude": (int(ExifTypes.RATIONAL), "gps"),
+    "gps_longitude_ref": (int(ExifTypes.ASCII), "gps"),
+    "gps_map_datum": (int(ExifTypes.ASCII), "gps"),
+    "gps_measure_mode": (int(ExifTypes.ASCII), "gps"),
+    "gps_satellites": (int(ExifTypes.ASCII), "gps"),
+    "gps_speed": (int(ExifTypes.RATIONAL), "gps"),
+    "gps_speed_ref": (int(ExifTypes.ASCII), "gps"),
+    "gps_status": (int(ExifTypes.ASCII), "gps"),
+    "gps_timestamp": (int(ExifTypes.RATIONAL), "gps"),
+    "gps_track": (int(ExifTypes.RATIONAL), "gps"),
+    "gps_track_ref": (int(ExifTypes.ASCII), "gps"),
+    "gps_version_id": (int(ExifTypes.BYTE), "gps"),
+    "image_description": (int(ExifTypes.ASCII), 0),
+    "image_unique_id": (int(ExifTypes.ASCII), "exif"),
+    "light_source": (int(ExifTypes.SHORT), "exif"),
+    "make": (int(ExifTypes.ASCII), 0),
+    "max_aperture_value": (int(ExifTypes.RATIONAL), 0),
+    "metering_mode": (int(ExifTypes.SHORT), "exif"),
+    "model": (int(ExifTypes.ASCII), 0),
+    "orientation": (int(ExifTypes.SHORT), 0),
+    "pixel_x_dimension": (int(ExifTypes.SHORT), "exif"),
+    "pixel_y_dimension": (int(ExifTypes.SHORT), "exif"),
+    "saturation": (int(ExifTypes.SHORT), "exif"),
+    "scene_capture_type": (int(ExifTypes.SHORT), "exif"),
+    "sensing_method": (int(ExifTypes.SHORT), "exif"),
+    "shutter_speed_value": (int(ExifTypes.SRATIONAL), "exif"),
+    "software": (int(ExifTypes.ASCII), 0),
+    "sharpness": (int(ExifTypes.SHORT), "exif"),
+    "spectral_sensitivity": (int(ExifTypes.ASCII), "exif"),
+    "subsec_time": (int(ExifTypes.ASCII), "exif"),
+    "subsec_time_original": (int(ExifTypes.ASCII), "exif"),
+    "subsec_time_digitized": (int(ExifTypes.ASCII), "exif"),
+    "subject_distance": (int(ExifTypes.RATIONAL), "exif"),
+    "subject_distance_range": (int(ExifTypes.SHORT), "exif"),
+    "subject_location": (int(ExifTypes.SHORT), "exif"),
+    "white_balance": (int(ExifTypes.SHORT), "exif"),
+    "_exif_ifd_pointer": (int(ExifTypes.LONG), 0),
+    "_gps_ifd_pointer": (int(ExifTypes.LONG), 0),
+}
 
-BYTES_PER_IFD_TAG_TYPE = 2
-
-BYTES_PER_IFD_TAG_COUNT = 4
-
-BYTES_PER_IFD_TAG_VALUE_OFFSET = 4
-
-BYTES_PER_IFD_TAG_TOTAL = (
-    BYTES_PER_IFD_TAG_ID + BYTES_PER_IFD_TAG_TYPE + BYTES_PER_IFD_TAG_COUNT +
-    BYTES_PER_IFD_TAG_VALUE_OFFSET
-)
 
 ERROR_IMG_NO_ATTR = "image does not have attribute {0}"
-
-EXIF_BIG_ENDIAN_HEADER = "4D4D"
-
-EXIF_LITTLE_ENDIAN_HEADER = "4949"
-
-EXIF_POINTER_TAG_ID = 34665
-
-GPS_POINTER_TAG_ID = 34853
-
-HEX_PER_BYTE = 2
-
-USER_COMMENT_CHARACTER_CODE_LEN_BYTES = 8
