@@ -1,5 +1,6 @@
 """Test deleting EXIF attributes."""
 
+import binascii
 import os
 import textwrap
 import unittest
@@ -14,7 +15,7 @@ from exif.tests.delete_exif_baselines import (
 # pylint: disable=pointless-statement, protected-access
 
 
-class TestModifyExif(unittest.TestCase):
+class TestDeleteExif(unittest.TestCase):
 
     """Test cases for deleting EXIF attributes."""
 
@@ -30,7 +31,7 @@ class TestModifyExif(unittest.TestCase):
         """Verify deleting all EXIF tags from the Image object."""
         self.image.delete_all()
 
-        segment_hex = self.image._segments['APP1'].get_segment_hex()
+        segment_hex = binascii.hexlify(self.image._segments['APP1'].get_segment_bytes()).decode("utf-8").upper()
         self.assertEqual('\n'.join(textwrap.wrap(segment_hex, 90)), DELETE_ALL_HEX_BASELINE)
 
         with TemporaryFile("w+b") as temporary_file_stream:
@@ -41,7 +42,7 @@ class TestModifyExif(unittest.TestCase):
         dunder_dir_text = '\n'.join(textwrap.wrap(repr(sorted(dir(reloaded_image))), 90))
         self.assertEqual(dunder_dir_text, Baseline("""
             ['<unknown EXIF tag 59932>', '_segments', 'delete', 'delete_all', 'get', 'get_file',
-            'get_thumbnail', 'has_exif', 'resolution_unit', 'x_resolution', 'y_resolution']
+            'get_thumbnail', 'has_exif']
             """))
 
     def test_delete_ascii_tags(self):
@@ -54,7 +55,7 @@ class TestModifyExif(unittest.TestCase):
         with self.assertRaisesRegex(AttributeError, "image does not have attribute model"):
             self.image.model
 
-        segment_hex = self.image._segments['APP1'].get_segment_hex()
+        segment_hex = binascii.hexlify(self.image._segments['APP1'].get_segment_bytes()).decode("utf-8").upper()
         self.assertEqual('\n'.join(textwrap.wrap(segment_hex, 90)), DELETE_ASCII_TAGS_HEX_BASELINE)
 
     def test_delete_gps_tags(self):
@@ -70,7 +71,7 @@ class TestModifyExif(unittest.TestCase):
         with self.assertRaisesRegex(AttributeError, "image does not have attribute gps_altitude"):
             self.image.gps_altitude
 
-        segment_hex = self.image._segments['APP1'].get_segment_hex()
+        segment_hex = binascii.hexlify(self.image._segments['APP1'].get_segment_bytes()).decode("utf-8").upper()
         self.assertEqual('\n'.join(textwrap.wrap(segment_hex, 90)), DELETE_GEOTAG_HEX_BASELINE)
 
     def test_delete_method(self):
