@@ -47,6 +47,13 @@ def test_index_accessor():
 
 
 def rounded_str(input_object):
+    """Trim string for consistency across test environments.
+
+    :param Object input_object: input value
+    :returns: rounded string
+    :rtype: str
+
+    """
     return str(input_object)[:13]
 
 
@@ -55,8 +62,11 @@ read_attributes_grand_canyon = [
     ("color_space", repr, "<ColorSpace.UNCALIBRATED: 65535>"),
     ("datetime", str, "2018:03:12 10:12:07"),
     ("exif_version", str, "0221"),
+    ("flash", str, "Flash(flash_fired=False, flash_return=FlashReturn.NO_STROBE_RETURN_DETECTION_FUNCTION, "
+                   "flash_mode=FlashMode.COMPULSORY_FLASH_SUPPRESSION, flash_function_not_present=False, "
+                   "red_eye_reduction_supported=False, reserved=0)"),
     ("gps_altitude", rounded_str, "2189.98969072"),
-    ("gps_altitude_ref", str, "0"),
+    ("gps_altitude_ref", repr, "<GpsAltitudeRef.ABOVE_SEA_LEVEL: 0>"),
     ("gps_latitude", str, "(36.0, 3.0, 11.08)"),
     ("gps_latitude_ref", str, "N"),
     ("gps_longitude", str, "(112.0, 5.0, 4.18)"),
@@ -77,7 +87,7 @@ read_attributes_grand_canyon = [
 
 # pylint: disable=line-too-long
 @pytest.mark.parametrize("attribute, func, value", read_attributes_grand_canyon, ids=[params[0] for params in read_attributes_grand_canyon])
-def test_read_grand_canyon(attribute, func, value):
+def test_read_file_object(attribute, func, value):
     """Test reading tags and compare to known baseline values."""
     with open(os.path.join(os.path.dirname(__file__), 'grand_canyon.jpg'), 'rb') as image_file:
         image = Image(image_file)
@@ -105,9 +115,37 @@ read_attributes_grayson_highlands = [
 
 # pylint: disable=line-too-long
 @pytest.mark.parametrize("attribute, func, value", read_attributes_grayson_highlands, ids=[params[0] for params in read_attributes_grayson_highlands])
-def test_read_grayson_highlands(attribute, func, value):
+def test_read_file_path(attribute, func, value):
     """Test reading tags and compare to known baseline values."""
-    with open(os.path.join(os.path.dirname(__file__), 'grayson_highlands.jpg'), 'rb') as image_file:
-        image = Image(image_file)
+    image = Image(os.path.join(os.path.dirname(__file__), 'grayson_highlands.jpg'))
+    assert func(getattr(image, attribute)) == value
+
+
+read_attributes_florida_beach = [
+    ("aperture_value", rounded_str, "1.69599381283"),
+    ("brightness_value", rounded_str, "9.46831050228"),
+    ("color_space", repr, "<ColorSpace.UNCALIBRATED: 65535>"),
+    ("datetime", str, "2019:03:26 19:33:47"),
+    ("flash", str, "Flash(flash_fired=False, flash_return=FlashReturn.NO_STROBE_RETURN_DETECTION_FUNCTION, "
+                   "flash_mode=FlashMode.AUTO_MODE, flash_function_not_present=False, "
+                   "red_eye_reduction_supported=False, reserved=0)"),
+    ("gps_altitude", rounded_str, "1.02077865606"),
+    ("gps_altitude_ref", repr, "<GpsAltitudeRef.ABOVE_SEA_LEVEL: 0>"),
+    ("gps_version_id", str, "2"),
+    ("make", str, "Apple"),
+    ("metering_mode", repr, "<MeteringMode.PATTERN: 5>"),
+    ("model", str, "iPhone 7"),
+    ("orientation", repr, "<Orientation.TOP_LEFT: 1>"),
+    ("resolution_unit", repr, "<ResolutionUnit.INCHES: 2>"),
+    ("white_balance", repr, "<WhiteBalance.AUTO: 0>"),
+]
+
+
+# pylint: disable=line-too-long
+@pytest.mark.parametrize("attribute, func, value", read_attributes_florida_beach, ids=[params[0] for params in read_attributes_florida_beach])
+def test_read_bytes(attribute, func, value):
+    """Test reading tags and compare to known baseline values."""
+    with open(os.path.join(os.path.dirname(__file__), 'florida_beach.jpg'), 'rb') as image_file:
+        image = Image(image_file.read())
 
     assert func(getattr(image, attribute)) == value
