@@ -1,5 +1,6 @@
 """Test special behavior for accessing user comment EXIF attribute."""
 
+import binascii
 import os
 import textwrap
 import unittest
@@ -28,10 +29,16 @@ class TestUserComment(unittest.TestCase):
         self.image.user_comment = "Updated user comment."
         self.assertEqual(self.image.user_comment, Baseline("""Updated user comment."""))
 
-        segment_hex = self.image._segments['APP1'].get_segment_hex()
+        segment_hex = binascii.hexlify(self.image._segments['APP1'].get_segment_bytes()).decode("utf-8").upper()
         self.assertEqual('\n'.join(textwrap.wrap(segment_hex, 90)),
                          MODIFY_USER_COMMENT_BASELINE)
 
+    def test_handle_ascii_too_long(self):
+        """Verify that writing a longer string to an ASCII tag raises a ValueError."""
+        with self.assertRaisesRegex(ValueError, "comment must be no longer than original"):
+            self.image.user_comment = ("This image shall be used in a package regression/unit test to verify reading "
+                                       "this user comment attribute which I'm making longer by adding this extra text.")
+
     def test_read(self):
         """Test reading a user comment."""
         self.assertEqual(
